#
# spec file for package redsea
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2017-2025, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           redsea
Version:        1.1.1
Release:        1.1
Summary:        An RDS decoder
License:        MIT
Group:          Productivity/Hamradio/Other
URL:            https://github.com/windytan/redsea
#Git-Clone:     https://github.com/windytan/redsea.git
Source:         https://github.com/windytan/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libliquid-devel
BuildRequires:  libsndfile-devel
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(nlohmann_json)
Recommends:     jq
Recommends:     rtl-sdr

%description
redsea is a command-line RDS (Radio Data System) decoder.
It can be used with any RTL-SDR USB radio stick with the rtl_fm tool.
It can also decode the raw ASCII bitstream, the hex format used by RDS Spy,
and audio files containing multiplex signals (MPX).

RDS groups are printed to the terminal as line-delimited JSON objects
or, optionally, undecoded hex blocks (-x).

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install

%files
%license LICENSE
%doc CHANGES.md README.md
%{_bindir}/redsea

%changelog
* Mon Mar  3 2025 Martin Hauke <mardnh@gmx.de>
- Update to version 1.1.1
  * Fix a regression in 1.1 that caused the groups to sometimes
    not appear immediately after reception.
  * Catch2 is an optional build dependency (building tests is
    optional).
* Sat Dec 28 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.1.0
  New features:
  * Decode 'broadcaster use' data in Slow labeling codes
    (variant 6).
  * Decode 'decoder identification' bits in Group 15B.
  * Workaround buggy encoders that show 1 extra character in
    RT+ fields.
  Bug fixes:
  * Fix a crash when the input file has a very high sample rate.
  * Fix a crash from uncaught iconv exceptions from corrupted
    utf8/ucs2 data.
  * Fix the CSVReader (used in the TMC decoder) ignoring the last
    line of any file.
  * Remove extra trailing space in transparent data channels
    hexdump.
  * Make raw libsndfile errors user-friendlier (instead of
    saying 'System error').
  Build system fixes:
  * Set default installation prefix to /usr/local.
  * Reduce compiler workload somewhat with forward declarations.
* Sat Jul 20 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.1
  Fixes:
  * Fix a crash (uncaught json exception) when attempting to
    serialize a string that's invalid UTF-8, e.g. if long PS gets
    corrupted.
  * Fix build when the installed version of nlohmann-json is too
    old.
  * Fix a couple of integer overflows, one affecting the
    subcarrier reset functionality (of #94) after 3.5 hours of
    runtime and another one causing a potential sync glitch after
    41 days of constant data.
* Thu Jun 27 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.0
  New features:
  * Add support for Enhanced RadioText (eRT).
  * Add support for Long PS in Group 15A.
  * Add runtime option --no-fec for disabling error correction.
  UX changes:
  * Breaking: Print a warning to stderr if the raw MPX input sample
    rate is not specified (breaks the previous silent assumption
    of 171 kHz)
  * Improve error reporting in general
  * Add --output hex (same as --output-hex) to mirror --input hex
  Fixes:
  * Fix detection of invalid date/time (timestamps >2000 years ago)
  * Noise resistance improvements.
    + Require three (instead of two) repeats of a new PI before
    accepting it for the JSON output
    + Require three (instead of two) synchronization pulses before
    locking.
  Maintainability:
  * Migrate build system from autotools to meson.
  * Switch from patched, packaged-in JsonCPP to external
    nlohmann-json.
  * Breaking: The order of some JSON elements has changed
    (insertion order instead of alphabetical)
  * Remove unmaintained build options for non-liquid, non-TMC
    builds.
  * Fix compiler warnings, issues identified via static analysis,
    and other code cleanup.
* Sun Jan 28 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 0.21
  * Add support for decoding LTCC and LTECC in TMC.
  * Add support for decoding RDS output from the TEF6686 tuner.
  * Add support for Alternative Frequencies Method B.
  * AF shown too less in JSON even for error-free signals.
  Breaking:
  * Change the name of the field alt_kilohertz to either
    alt_frequencies_a or alt_frequencies_b. The type of data sent
    by these methods differs. When --show-partial is set, the AF
    list will be in partial_alt_frequencies regardless of method.
  * Add option --input / -i to specify the stdin input format
    (bits, hex, mpx, tef). The old options will still work.
  * Fix automake script on Windows.
  * Fix compatibility with current liquid-dsp.
  * Fix output for UTF-8 encoded TMC location tables.
  * Fix clock_time displaying wrong date around midnightj
  * Fix misinterpretation of the Decoder Identification bits.
  * Fix decoding of RadioText for stations that don't use string
    terminators.
  * Show RadioText for stations that don't transmit end-of-message
    code.
  * Fix an off-by-one bug in the RadioText decoder that sometimes
    caused missing characters at the end of messages.
  * Fix runaway PLL after digital silence by clamping the phase
    error.
* Mon Mar  8 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.20
  * Recognize more ODAs and features.
  * Add support for PTY names (group 10A).
  * Add partial support for DAB cross-referencing.
  * Add support for raw broadcaster data in EON (variant 15).
  * Add support for transparent data channels (groups 5A, 5B).
  * Add support for fractional seconds in the rx timestamp
    format (%%f).
  * Add support for TMC tuning info variant 8.
  * Add buffer delay compensation to rx timestamps. Timestamps
    aim to represent the time the PCM samples were read in.
  * Place some JSON fields in the beginning of the line for
    easier visual inspection (pi, group, ps...).
  * Print raw ODA data if the application is not supported.
* Mon Apr  6 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.19
  * Add option --show-raw (-R) for including the raw group data
    as a hex string in the JSON output
  * Print usage help if there are non-option arguments on the
    command line
  * Fix uninitialized block error rate values on some systems
  * Update jsoncpp from 1.8.1 to 1.8.4 to fix some warnings
* Sun May 19 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18
  * Add support for loading multiple TMC location databases by
    specifying --loctable more than once.
  * Sample rate can also be specified as -r 171k instead of -r 171000.
  * Fix a crash if the input audio file couldn't be loaded.
  * Print usage help instead of error message when stdin is empty.
  * Speed up loading of TMC location database.
  * Improve block sync detection by ignoring spurious sync pulses.
  * Fine-tune filter bandwidths for better sensitivity, based on
    test runs.
  * At EOF, process the last partially received group.
  * Remove character codetables G1 and G2 since they don't appear
    in the latest RDS standard any more.
  * Clean up code to ensure maintainability. Redsea now requires
    a compiler that supports C++14.
* Fri Dec 14 2018 Jan Engelhardt <jengelh@inai.de>
- Trim bias, extend description.
* Fri Jun  8 2018 mardnh@gmx.de
- Update to version 0.17.1
  Bugfix release.
  * Return exit value 0 if --version or --help was requested
  * Don't open stdout for libsndfile unless --feed-through was
    specified, otherwise json can't be written (this may break the
    feed-through on Linux temporarily)
* Tue Jun  5 2018 mardnh@gmx.de
- Update to version 0.17.0
  * Change the type of the JSON field for TMC message urgency, from
    integer (0, 1, 2) to string ("none", "U", "X"), to better match
    its values in the specification
  * Speed improvements by avoiding a few extraneous buffer copies
    internally
* Tue Mar 27 2018 mardnh@gmx.de
- Update to version 0.16.0
  * Add support for multi-channel signals (--channels) - libsndfile
    is now a required dependency
  * Speed improvements: ◦By using a lookup table instead of sinf/cosf
    to generate the mix-down sinusoid
  * By only using one mix-down operation instead of two
* Wed Jan 31 2018 mardnh@gmx.de
- Update to version 0.15.0
  * Add prog_item_number field containing the raw Program Item Number
  * Add partial_alt_kilohertz field containing an incomplete list of
    alternative frequencies when the --show-partial option is used
  * Add configure option --without-macports to disable directory checks
    when cross-compiling
  * Reduce write calls to output JSON stream using a streamstring
* Sat Dec  9 2017 mardnh@gmx.de
- Update to version 0.14.1
  * Don't consider UTC+14 invalid (it's the time zone in Kiribati)
  * Use JSON object callsign_uncertain for call signs of stations whose
  * PI code begins with a 1
  * Fix syntax errors in schema
* Thu Nov 16 2017 mardnh@gmx.de
- Update to version 0.14
  * Added support for decoding call sign letters from North American
    (RBDS) stations - activated by the -u switch. These are very
    noise-resistant as they're based on the PI code.
* Tue Sep 19 2017 mardnh@gmx.de
- Update to version 0.13
  * Change the JSON structure in radiotext_plus: RT+ tags are now displayed as
    an array of objects with content-type and data
  * Change the way frequencies are displayed for better machine readability, from
    "frequency":"87.9 MHz" to "kilohertz":87900
  * Update jsoncpp from version 1.7.7 to 1.8.1
* Sat Jul 22 2017 mardnh@gmx.de
- Update to version 0.12
  * Add support for time-of-demodulation timestamps (-t, --timestamp)
  * Add support for average block error rate (BLER) estimation (-E, --bler)
  * Change the long option for -b to --input-bits and fix the incorrect
    option in the usage help
* Mon Apr 17 2017 mardnh@gmx.de
- Update to version 0.11
  * Add support for TMC alternative frequencies (tuning info variant 6)
  * Add support for TMC gap parameter and enhanced mode (3A group variant 1)
  * Change JSON schema for TMC: encryption_id is now under system_info
  * Change PLL bandwidth and lowpass cutoff frequency to improve noise performance
  * Change resampler anti-alias cutoff frequency to allow for lower sample rates
  * Fix missing zero-padding in PIN time string
  * Fix uninitialized PI field occasionally getting printed when the actual PI is missed
  * Fix some names not getting read properly from the location database
  * Fix grammar in some TMC event descriptions
  * Fix potentially uninitialized data printout when a type 6B group was not fully received
  * Fix potentially uninitialized RadioText+ tags when the group was not fully received
  * Fix spurious printouts of "version B" groups when the C' offset was not seen
* Mon Apr  3 2017 mardnh@gmx.de
- initial package, version 0.10.0
